@@ -69,7 +69,7 @@ define!({
     pub enum Value {
         SquareBracketBlock(SquareBracketBlock),
 
-        Paren(ParenValue),
+        RoundBracketBlock(RoundBracketBlock),
 
         Unit(UnitValue),
 
@@ -128,10 +128,9 @@ define!({
         pub args: Vec<Value>,
     }
 
-    pub struct ParenValue {
+    pub struct RoundBracketBlock {
         pub span: Span,
-
-        pub value: Option<Box<Value>>,
+        pub children: Option<Vec<Value>>,
     }
 
     pub struct SquareBracketBlock {
